pub struct SsboMesh;Expand description
Resource representing the SSBO mesh data. It is filled by every GpuMesh if use_ssbo is set to true. The position of the vertex and index data in the buffers is then stored in the GpuMesh resource.
Implementations
Sourceimpl SsboMesh
impl SsboMesh
pub const VERTEX_BUFFER_ID: u32 = 0
pub const INDEX_BUFFER_ID: u32 = 1