pub struct SsboMeshBinding;Trait Implementations
Sourceimpl Clone for SsboMeshBinding
impl Clone for SsboMeshBinding
Sourcefn clone(&self) -> SsboMeshBinding
fn clone(&self) -> SsboMeshBinding
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for SsboMeshBinding
impl Default for SsboMeshBinding
Sourcefn default() -> SsboMeshBinding
fn default() -> SsboMeshBinding
Returns the “default value” for a type. Read more
Sourceimpl RenderBinding for SsboMeshBinding
impl RenderBinding for SsboMeshBinding
type Params = Res<'static, RenderAssets<GpuRenderData<SsboMesh>>>
Sourcefn describe(
&mut self,
render_binding: &SystemParamItem<'_, '_, Self::Params>,
builder: &mut RenderBindingBuilder,
)
fn describe( &mut self, render_binding: &SystemParamItem<'_, '_, Self::Params>, builder: &mut RenderBindingBuilder, )
Describes the render binding. This is used to specify the
RenderData that should be used to create the bind group layout and bind group entries, and to specify the binding index for each buffer and texture.Sourceimpl TypePath for SsboMeshBinding
impl TypePath for SsboMeshBinding
Sourcefn type_path() -> &'static str
fn type_path() -> &'static str
Returns the fully qualified path of the underlying type. Read more
Sourcefn short_type_path() -> &'static str
fn short_type_path() -> &'static str
Returns a short, pretty-print enabled path to the type. Read more
Sourcefn type_ident() -> Option<&'static str>
fn type_ident() -> Option<&'static str>
Sourcefn crate_name() -> Option<&'static str>
fn crate_name() -> Option<&'static str>
Sourceimpl VisitAssetDependencies for SsboMeshBinding
impl VisitAssetDependencies for SsboMeshBinding
fn visit_dependencies(&self, visit: &mut impl FnMut(UntypedAssetId))
impl Asset for SsboMeshBinding